---
title: Accessibility
tabName: Main terms
---

> Our core components meet basic accessibility requirements. You can find component-specific details in the component guides.

@## About accessibility

<!-- > 💡 Accessibility (a11y) is a measure of how accessible a computer system is to all people, including those with disabilities or impairments. It concerns both software and hardware and how they are configured in order to enable a disabled or impaired person to use that computer system successfully. -->

<!-- Accessibility is also known as assistive technology. -->

Accessibility relates to design principles in software development that are aimed at making information and interaction with the interface more accessible when used by people with disabilities, or under specific conditions or circumstances.

<!-- Interface designed with accessibility in mind can convert text-to-speech or output to specialized braille equipment for the visually impaired. -->

<!-- Media such as images and videos can also be accessible. _An example of accessibility embedded in media is subtitles. In this case, the film may not be made for the hearing impaired, but subtitles help in making film accessible to people with hearing impairments._ -->

@## Why it's important

- An interface designed with accessibility in mind is an interface that everyone can use equally. This is beneficial not just for the users, but for the site owners as well, since it increases their audience.
- Accessibility isn't just about making UI usable for people with disabilities and health issues, but also about making user experience more comfortable in different conditions (bright sun, noisy environment, limited movement, etc.).
- Lack of accessibility options could open the company up to fines or lawsuits.
- Making the UI accessible for everyone. As technologies evolve and develop, they are used by more and more people all over the world.

@## Main terms and definitions

- _Accessibility_ is abbreviated as _a11y_. This is a so-called numeronym, where the number in the middle refers to the number of letters the word contains between the first and last letter. This abbreviation technique is mostly used in the software development community.
- **[WAI-ARIA](https://www.w3.org/WAI/standards-guidelines/aria/)** or Accessible Rich Internet Applications is a suite of web standards that defines ways to make content and applications accessible to people with disabilities.
- **[ARIA in HTML](https://www.w3.org/TR/html-aria/)** is a technical specification on the use of special HTML attributes (prefixed with `aria-`) that help assistive technologies like screen readers navigate and interact with the interface.
- **[WCAG](https://www.w3.org/TR/WCAG20/)** or Web Content Accessibility Guidelines are a set of recommendations for making web content more accessible that are developed by a separate working group within the [W3C](https://www.w3.org/).
- **[ARIA Live Region](https://www.w3.org/TR/wai-aria-1.2/#dfn-live-region)** is a dynamically changing part of the interface such as chats, progress bars, alerts, etc. These are the perceived areas of the pages that are usually updated as a result of an external event when the user has focused somewhere else. The main purpose of these areas is to tell screen readers how to properly handle content changes that are not necessarily user-dependent.
- **Screen Readers** (VoiceOver on [Mac](https://youtu.be/5R-6WvAihms) and [iOS](https://youtu.be/bCHpdjvxBws), [TalkBack](https://youtu.be/0Zpzl4EKCco) on Android, [NVDA](https://youtu.be/Jao3s_CwdRU) or JAWS for Windows) are assistive technology applications designed for the blind and visually impaired. These applications render text, image content, or interface elements as speech, and provide sound and vibration feedback.

@## Useful links

- **[The A11Y Project](https://a11yproject.com/)** is a community-driven project where participants share best practices and ways to improve digital accessibility.
- **[WebAIM](https://webaim.org/)** or Web Accessibility in Mind is a non-profit organization from the University of Utah, USA. It is actively involved in the development of standards, techniques and approaches for improving accessibility, and also provides accessibility consulting and training for the web community.
- **[Index of ARIA Design Pattern Examples](https://www.w3.org/TR/wai-aria-practices-1.1/examples/)** includes the indexes of example implementations of ARIA design patterns included in [WAI-ARIA Authoring Practices 1.1](https://www.w3.org/TR/wai-aria-practices-1.1/).

@page a11y-general
@page a11y-keyboard
@page a11y-design
